# BlankSpaceBaby
中文英文排版方法（How to Typeset Chinese and English Text）

## 安裝（Installation）
```bash
pip install blankspacebaby
```

## 使用（Usage）
```bash
blankspacebaby -l zh
```
You will see an interactive prompt. Type in the text you want to typeset and press Control + D. The typeset text will be printed out.


## 準則（Guidelines）
- 中英文之間需要空格（There should be a space between Chinese and English）
  
> e.g. 打中文搭配 English 是件很 Hiphop 的事。

- 中文與數字之間需要空格（There should be a space between Chinese and numbers）
  
> e.g. 我有 3 顆蘋果。

- 中文（全行）標點符號與其他符號之間不需要空格（There should be no space between Chinese punctuation and other symbols）

> e.g.  我的英文名字是 Jason。